==> tpcclib-0.7.9-src.tar.gz: v2/libtpctac/test_tpctac.h <==
#ifndef _TEST_TPCTAC_H_
#define _TEST_TPCTAC_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
/*****************************************************************************/
#include "tpctac.h"
/*****************************************************************************/

/*****************************************************************************/
/* tac */
extern int test_tacInit(TPCSTATUS *status);
extern int test_taccInit(TPCSTATUS *status);
extern int test_tacFreeExceptHeader(TPCSTATUS *status);
extern int test_tacFree(TPCSTATUS *status);
extern int test_taccFree(TPCSTATUS *status);
extern int test_tacAllocate(TPCSTATUS *status);
extern int test_tacAllocateMore(TPCSTATUS *status);
extern int test_tacCopyTacc(TPCSTATUS *status);
extern int test_tacCopyTaccdata(TPCSTATUS *status);
extern int test_tacCopyTacchdr(TPCSTATUS *status);
extern int test_tacCopyHdr(TPCSTATUS *status);
extern int test_tacIsSize(TPCSTATUS *status);
extern int test_tacDuplicate(TPCSTATUS *status);
extern int test_tacExtract(TPCSTATUS *status);
extern int test_tacAllocateMoreSamples(TPCSTATUS *status);
/* helper functions */
extern int create_tac(TAC *tac);
extern int create_tac2(TAC *tac);
/*****************************************************************************/

/*****************************************************************************/
/* mtac */
extern int test_mtacInit(TPCSTATUS *status);
extern int test_mtacFree(TPCSTATUS *status);
extern int test_mtacAllocate(TPCSTATUS *status);
extern int test_mtacAllocateMore(TPCSTATUS *status);
extern int test_mtacAddTAC(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* tacio */
extern int test_tacFormattxt(TPCSTATUS *status);
extern int test_tacFormatIdentify(TPCSTATUS *status);
extern int test_tacFormatDetermine(TPCSTATUS *status);
extern int test_tacFormatWriteSupported(TPCSTATUS *status);
extern int test_tacWrite(TPCSTATUS *status);
extern int test_tacRead(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* tacift */
extern int test_tacGetHeaderStudynr(TPCSTATUS *status);
extern int test_tacSetHeaderStudynr(TPCSTATUS *status);
extern int test_tacGetHeaderUnit(TPCSTATUS *status);
extern int test_tacSetHeaderUnit(TPCSTATUS *status);
extern int test_tacGetHeaderTimeunit(TPCSTATUS *status);
extern int test_tacSetHeaderTimeunit(TPCSTATUS *status);
extern int test_tacGetHeaderIsotope(TPCSTATUS *status);
extern int test_tacSetHeaderIsotope(TPCSTATUS *status);
extern int test_tacGetHeaderScanstarttime(TPCSTATUS *status);
extern int test_tacSetHeaderScanstarttime(TPCSTATUS *status);
extern int test_tacGetHeaderInjectiontime(TPCSTATUS *status);
extern int test_tacSetHeaderInjectiontime(TPCSTATUS *status);
extern int test_tacGetHeaderDecayCorrection(TPCSTATUS *status);
extern int test_tacSetHeaderDecayCorrection(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* simpleio */
extern int test_tacWriteSimple(TPCSTATUS *status);
extern int test_tacReadSimple(TPCSTATUS *status);
/*****************************************************************************/
/* dftio */
extern int test_tacNameSplit(TPCSTATUS *status);
extern int test_tacWriteDFT(TPCSTATUS *status);
extern int test_tacReadDFT(TPCSTATUS *status);
/*****************************************************************************/
/* sifio */
extern int test_tacWriteSIF(TPCSTATUS *status);
extern int test_tacReadSIF(TPCSTATUS *status);
/* helper functions */
extern int create_sif(TAC *tac);
/*****************************************************************************/
/* pmodio */
extern int test_tacWritePMOD(TPCSTATUS *status);
extern int test_tacReadPMOD(TPCSTATUS *status);
/*****************************************************************************/
/* qviewio */
extern int test_tacReadQView(TPCSTATUS *status);
/*****************************************************************************/
/* matio */
extern int test_tacReadMat(TPCSTATUS *status);
/*****************************************************************************/
/* taccsv */
extern int test_tacWriteCSV(TPCSTATUS *status);
extern int test_tacReadCSV(TPCSTATUS *status);
extern int test_tacReadInveonCSV(TPCSTATUS *status);
extern int test_tacReadCarimasTxt(TPCSTATUS *status);
/*****************************************************************************/
/* hcio */
extern int test_tacReadHRRTHC(TPCSTATUS *status);
extern int test_tacReadHRPLUSHC(TPCSTATUS *status);
/*****************************************************************************/
/* tacnan */
extern int test_tacXNaNs(TPCSTATUS *status);
extern int test_tacYNaNs(TPCSTATUS *status);
extern int test_tacNaNs(TPCSTATUS *status);
extern int test_tacNotNaNs(TPCSTATUS *status);
extern int test_tacFixNaNs(TPCSTATUS *status);
extern int test_tacNthSample(TPCSTATUS *status);
/*****************************************************************************/
/* tacselect */
extern int test_tacSelectedTACs(TPCSTATUS *status);
extern int test_tacFirstSelected(TPCSTATUS *status);
extern int test_tacSelectTACs(TPCSTATUS *status);
extern int test_tacSelectBestReference(TPCSTATUS *status);
/*****************************************************************************/
/* tacorder */
extern int test_tacVerifyTimeOrder(TPCSTATUS *status);
extern int test_tacSortByTime(TPCSTATUS *status);
extern int test_tacSortByConc(TPCSTATUS *status);
extern int test_tacSortByName(TPCSTATUS *status);
extern int test_tacSortByAUC(TPCSTATUS *status);
extern int test_tacMoveTACC(TPCSTATUS *status);
extern int test_tacSwapTACCs(TPCSTATUS *status);
extern int test_tacDeleteTACC(TPCSTATUS *status);
extern int test_tacMultipleSamples(TPCSTATUS *status);
/*****************************************************************************/
/* taccomp */
extern int test_tacCompareUnit(TPCSTATUS *status);
extern int test_tacCompareNames(TPCSTATUS *status);
extern int test_tacCompareConc(TPCSTATUS *status);
extern int test_tacCompareTimes(TPCSTATUS *status);
extern int test_tacCompareWeights(TPCSTATUS *status);
/*****************************************************************************/
/* tacunits */
extern int test_tacXUnitConvert(TPCSTATUS *status);
extern int test_tacYUnitConvert(TPCSTATUS *status);
extern int test_tacYUnitMass2Volume(TPCSTATUS *status);
extern int test_tacYUnitVolume2Mass(TPCSTATUS *status);
/*****************************************************************************/
/* tacname */
extern int test_tacIndividualNames(TPCSTATUS *status);
extern int test_tacEnsureNames(TPCSTATUS *status);
/*****************************************************************************/
/* tacx */
extern int test_tacXCopy(TPCSTATUS *status);
extern int test_tacCorrectFrameOverlap(TPCSTATUS *status);
extern int test_tacXRange(TPCSTATUS *status);
extern int test_tacSampleXRange(TPCSTATUS *status);
extern int test_tacMinX(TPCSTATUS *status);
extern int test_tacIsX(TPCSTATUS *status);
extern int test_tacXMatch(TPCSTATUS *status);
extern int test_tacAddZeroSample(TPCSTATUS *status);
extern int test_tacDeleteSample(TPCSTATUS *status);
extern int test_tacDeleteMissingSamples(TPCSTATUS *status);
extern int test_tacExtractRange(TPCSTATUS *status);
extern int test_tacExtractSamples(TPCSTATUS *status);
extern int test_tacCheckX1X2X(TPCSTATUS *status);
extern int test_tacSetX(TPCSTATUS *status);
extern int test_tacGetSampleInterval(TPCSTATUS *status);
extern int test_tacToBars(TPCSTATUS *status);
/*****************************************************************************/
/* tacy */
extern int test_tacYRange(TPCSTATUS *status);
extern int test_tacYRangeInXRange(TPCSTATUS *status);
/*****************************************************************************/
/* tacw */
extern int test_tacIsWeighted(TPCSTATUS *status);
extern int test_tacWCopy(TPCSTATUS *status);
extern int test_tacWMove(TPCSTATUS *status);
extern int test_tacWByFreq(TPCSTATUS *status);
extern int test_tacWSampleNr(TPCSTATUS *status);
extern int test_tacWeightNorm(TPCSTATUS *status);
extern int test_tacWeightModerate(TPCSTATUS *status);
extern int test_sifWeight(TPCSTATUS *status);
extern int test_tacSetWeights(TPCSTATUS *status);
/*****************************************************************************/
/* tacdc */
extern int test_tacGetIsotope(TPCSTATUS *status);
extern int test_tacSetIsotope(TPCSTATUS *status);
extern int test_tacDecayCorrection(TPCSTATUS *status);
/*****************************************************************************/
/* tacabss */
extern int test_tacReadAllogg(TPCSTATUS *status);
extern int test_tacReadOldAllogg(TPCSTATUS *status);
extern int test_tacReadScanditronics(TPCSTATUS *status);
extern int test_tacReadGEMS(TPCSTATUS *status);
/*****************************************************************************/
/* tacxmlio */
extern int test_tacWriteXML(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCTAC */

==> tpcclib-0.8.0-src.tar.gz: v2/libtpctac/test_tpctac.h <==
#ifndef _TEST_TPCTAC_H_
#define _TEST_TPCTAC_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
/*****************************************************************************/
#include "tpctac.h"
/*****************************************************************************/

/*****************************************************************************/
/* tac */
extern int test_tacInit(TPCSTATUS *status);
extern int test_taccInit(TPCSTATUS *status);
extern int test_tacFreeExceptHeader(TPCSTATUS *status);
extern int test_tacFree(TPCSTATUS *status);
extern int test_taccFree(TPCSTATUS *status);
extern int test_tacAllocate(TPCSTATUS *status);
extern int test_tacAllocateMore(TPCSTATUS *status);
extern int test_tacCopyTacc(TPCSTATUS *status);
extern int test_tacCopyTaccdata(TPCSTATUS *status);
extern int test_tacCopyTacchdr(TPCSTATUS *status);
extern int test_tacCopyHdr(TPCSTATUS *status);
extern int test_tacIsSize(TPCSTATUS *status);
extern int test_tacDuplicate(TPCSTATUS *status);
extern int test_tacExtract(TPCSTATUS *status);
extern int test_tacAllocateMoreSamples(TPCSTATUS *status);
/* helper functions */
extern int create_tac(TAC *tac);
extern int create_tac2(TAC *tac);
extern int create_inp1(TAC *tac);
/*****************************************************************************/

/*****************************************************************************/
/* mtac */
extern int test_mtacInit(TPCSTATUS *status);
extern int test_mtacFree(TPCSTATUS *status);
extern int test_mtacAllocate(TPCSTATUS *status);
extern int test_mtacAllocateMore(TPCSTATUS *status);
extern int test_mtacAddTAC(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* tacio */
extern int test_tacFormattxt(TPCSTATUS *status);
extern int test_tacFormatIdentify(TPCSTATUS *status);
extern int test_tacFormatDetermine(TPCSTATUS *status);
extern int test_tacFormatWriteSupported(TPCSTATUS *status);
extern int test_tacWrite(TPCSTATUS *status);
extern int test_tacRead(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* tacift */
extern int test_tacGetHeaderStudynr(TPCSTATUS *status);
extern int test_tacSetHeaderStudynr(TPCSTATUS *status);
extern int test_tacGetHeaderUnit(TPCSTATUS *status);
extern int test_tacSetHeaderUnit(TPCSTATUS *status);
extern int test_tacGetHeaderTimeunit(TPCSTATUS *status);
extern int test_tacSetHeaderTimeunit(TPCSTATUS *status);
extern int test_tacGetHeaderIsotope(TPCSTATUS *status);
extern int test_tacSetHeaderIsotope(TPCSTATUS *status);
extern int test_tacGetHeaderScanstarttime(TPCSTATUS *status);
extern int test_tacSetHeaderScanstarttime(TPCSTATUS *status);
extern int test_tacGetHeaderInjectiontime(TPCSTATUS *status);
extern int test_tacSetHeaderInjectiontime(TPCSTATUS *status);
extern int test_tacGetHeaderDecayCorrection(TPCSTATUS *status);
extern int test_tacSetHeaderDecayCorrection(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* simpleio */
extern int test_tacWriteSimple(TPCSTATUS *status);
extern int test_tacReadSimple(TPCSTATUS *status);
/*****************************************************************************/
/* dftio */
extern int test_tacNameSplit(TPCSTATUS *status);
extern int test_tacWriteDFT(TPCSTATUS *status);
extern int test_tacReadDFT(TPCSTATUS *status);
/*****************************************************************************/
/* sifio */
extern int test_tacWriteSIF(TPCSTATUS *status);
extern int test_tacReadSIF(TPCSTATUS *status);
/* helper functions */
extern int create_sif(TAC *tac);
/*****************************************************************************/
/* pmodio */
extern int test_tacWritePMOD(TPCSTATUS *status);
extern int test_tacReadPMOD(TPCSTATUS *status);
/*****************************************************************************/
/* qviewio */
extern int test_tacReadQView(TPCSTATUS *status);
/*****************************************************************************/
/* 4dmio */
extern int test_tacRead4DM(TPCSTATUS *status);
/*****************************************************************************/
/* matio */
extern int test_tacReadMat(TPCSTATUS *status);
/*****************************************************************************/
/* taccsv */
extern int test_tacWriteCSV(TPCSTATUS *status);
extern int test_tacReadCSV(TPCSTATUS *status);
extern int test_tacReadInveonCSV(TPCSTATUS *status);
extern int test_tacReadCarimasTxt(TPCSTATUS *status);
/*****************************************************************************/
/* hcio */
extern int test_tacReadHRRTHC(TPCSTATUS *status);
extern int test_tacReadHRPLUSHC(TPCSTATUS *status);
/*****************************************************************************/
/* tacnan */
extern int test_tacXNaNs(TPCSTATUS *status);
extern int test_tacYNaNs(TPCSTATUS *status);
extern int test_tacNaNs(TPCSTATUS *status);
extern int test_tacNotNaNs(TPCSTATUS *status);
extern int test_tacFixNaNs(TPCSTATUS *status);
extern int test_tacNthSample(TPCSTATUS *status);
/*****************************************************************************/
/* tacselect */
extern int test_tacSelectedTACs(TPCSTATUS *status);
extern int test_tacFirstSelected(TPCSTATUS *status);
extern int test_tacSelectTACs(TPCSTATUS *status);
extern int test_tacSelectBestReference(TPCSTATUS *status);
/*****************************************************************************/
/* tacorder */
extern int test_tacVerifyTimeOrder(TPCSTATUS *status);
extern int test_tacSortByTime(TPCSTATUS *status);
extern int test_tacSortByConc(TPCSTATUS *status);
extern int test_tacSortByName(TPCSTATUS *status);
extern int test_tacSortByAUC(TPCSTATUS *status);
extern int test_tacMoveTACC(TPCSTATUS *status);
extern int test_tacSwapTACCs(TPCSTATUS *status);
extern int test_tacDeleteTACC(TPCSTATUS *status);
extern int test_tacMultipleSamples(TPCSTATUS *status);
/*****************************************************************************/
/* taccomp */
extern int test_tacCompareUnit(TPCSTATUS *status);
extern int test_tacCompareNames(TPCSTATUS *status);
extern int test_tacCompareConc(TPCSTATUS *status);
extern int test_tacCompareTimes(TPCSTATUS *status);
extern int test_tacCompareWeights(TPCSTATUS *status);
/*****************************************************************************/
/* tacunits */
extern int test_tacXUnitConvert(TPCSTATUS *status);
extern int test_tacYUnitConvert(TPCSTATUS *status);
extern int test_tacYUnitMass2Volume(TPCSTATUS *status);
extern int test_tacYUnitVolume2Mass(TPCSTATUS *status);
/*****************************************************************************/
/* tacname */
extern int test_tacIndividualNames(TPCSTATUS *status);
extern int test_tacEnsureNames(TPCSTATUS *status);
/*****************************************************************************/
/* tacx */
extern int test_tacXCopy(TPCSTATUS *status);
extern int test_tacCorrectFrameOverlap(TPCSTATUS *status);
extern int test_tacXRange(TPCSTATUS *status);
extern int test_tacSampleXRange(TPCSTATUS *status);
extern int test_tacMinX(TPCSTATUS *status);
extern int test_tacIsX(TPCSTATUS *status);
extern int test_tacXMatch(TPCSTATUS *status);
extern int test_tacAddZeroSample(TPCSTATUS *status);
extern int test_tacDeleteSample(TPCSTATUS *status);
extern int test_tacDeleteMissingSamples(TPCSTATUS *status);
extern int test_tacExtractRange(TPCSTATUS *status);
extern int test_tacExtractSamples(TPCSTATUS *status);
extern int test_tacCheckX1X2X(TPCSTATUS *status);
extern int test_tacSetX(TPCSTATUS *status);
extern int test_tacGetSampleInterval(TPCSTATUS *status);
extern int test_tacToBars(TPCSTATUS *status);
extern int test_tacFramesToSteps(TPCSTATUS *status);
extern int test_tacIsXContiguous(TPCSTATUS *status);
extern int test_tacSetXContiguous(TPCSTATUS *status);
/*****************************************************************************/
/* tacy */
extern int test_tacYRange(TPCSTATUS *status);
extern int test_tacYRangeInXRange(TPCSTATUS *status);
/*****************************************************************************/
/* tacw */
extern int test_tacIsWeighted(TPCSTATUS *status);
extern int test_tacWCopy(TPCSTATUS *status);
extern int test_tacWMove(TPCSTATUS *status);
extern int test_tacWByFreq(TPCSTATUS *status);
extern int test_tacWSampleNr(TPCSTATUS *status);
extern int test_tacWeightNorm(TPCSTATUS *status);
extern int test_tacWeightModerate(TPCSTATUS *status);
extern int test_sifWeight(TPCSTATUS *status);
extern int test_tacSetWeights(TPCSTATUS *status);
/*****************************************************************************/
/* tacdc */
extern int test_tacGetIsotope(TPCSTATUS *status);
extern int test_tacSetIsotope(TPCSTATUS *status);
extern int test_tacDecayCorrection(TPCSTATUS *status);
/*****************************************************************************/
/* tacabss */
extern int test_tacReadAllogg(TPCSTATUS *status);
extern int test_tacReadOldAllogg(TPCSTATUS *status);
extern int test_tacReadScanditronics(TPCSTATUS *status);
extern int test_tacReadGEMS(TPCSTATUS *status);
/*****************************************************************************/
/* tacxmlio */
extern int test_tacWriteXML(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCTAC */
